# bmkg-dashboard
this package is dashboard for BMKG indonesian earthquake live and last article

## How it work?
this package will scarape in [BMKG](https://bmkg.go.id) to get latest earthquake and article, use BeautifulSoup4 and requests.
and then produce output of JSON thats ready to use in your web or mobile apps
